@@ -492,7 +492,7 @@ setMethod(
       SpatialPointsDataFrame(
         trackDF[!outliers, c('location_long', 'location_lat')],
         data = trackDF[!outliers, ],
-        proj4string = CRS("+proj=longlat +ellps=WGS84 +datum=WGS84"),
+        proj4string = CRS("+proj=longlat +datum=WGS84"),
         match.ID = T
       )
     
@@ -865,4 +865,4 @@ setMethod(f="getMovebankReferenceTable",
           definition = function(study, login, allAttributes){
             login <- movebankLogin()
             getMovebankReferenceTable(study=study,login=login,allAttributes=FALSE)
-          })
\ No newline at end of file
+          })
